@@ -1,8 +1,7 @@
-from fastapi import APIRouter
-
 from fidesops.api.v1.endpoints import (
     config_endpoints,
     connection_endpoints,
+    connection_type_endpoints,
     dataset_endpoints,
     drp_endpoints,
     encryption_endpoints,
@@ -17,9 +16,11 @@ from fidesops.api.v1.endpoints import (
     user_endpoints,
     user_permission_endpoints,
 )
+from fidesops.util.api_router import APIRouter
 
 api_router = APIRouter()
 api_router.include_router(config_endpoints.router)
+api_router.include_router(connection_type_endpoints.router)
 api_router.include_router(connection_endpoints.router)
 api_router.include_router(dataset_endpoints.router)
 api_router.include_router(drp_endpoints.router)
