@@ -6,21 +6,30 @@ from enum import Enum as EnumType
 from typing import Any, Dict, List, Optional
 
 from celery.result import AsyncResult
+from fideslib.cryptography.cryptographic_util import hash_with_salt
+from fideslib.db.base import Base
+from fideslib.db.base_class import FidesBase
+from fideslib.models.audit_log import AuditLog
+from fideslib.models.client import ClientDetail
+from fideslib.models.fides_user import FidesUser
+from fideslib.oauth.jwt import generate_jwe
 from pydantic import root_validator
 from sqlalchemy import Column, DateTime
 from sqlalchemy import Enum as EnumColumn
 from sqlalchemy import ForeignKey, String
 from sqlalchemy.dialects.postgresql import JSONB
-from sqlalchemy.ext.mutable import MutableList
+from sqlalchemy.ext.mutable import MutableDict, MutableList
 from sqlalchemy.orm import Session, backref, relationship
+from sqlalchemy_utils.types.encrypted.encrypted_type import (
+    AesGcmEngine,
+    StringEncryptedType,
+)
 
 from fidesops.api.v1.scope_registry import PRIVACY_REQUEST_CALLBACK_RESUME
 from fidesops.common_exceptions import PrivacyRequestPaused
-from fidesops.db.base_class import Base, FidesopsBase
+from fidesops.core.config import config
+from fidesops.db.base_class import JSONTypeOverride
 from fidesops.graph.config import CollectionAddress
-from fidesops.models.audit_log import AuditLog
-from fidesops.models.client import ClientDetail
-from fidesops.models.fidesops_user import FidesopsUser
 from fidesops.models.policy import (
     ActionType,
     PausedStep,
@@ -50,7 +59,6 @@ from fidesops.util.cache import (
     get_masking_secret_cache_key,
 )
 from fidesops.util.collection_util import Row
-from fidesops.util.oauth_util import generate_jwe
 
 logger = logging.getLogger(__name__)
 
@@ -69,7 +77,7 @@ class ManualAction(BaseSchema):
 
     @root_validator
     @classmethod
-    def get_or_update_details(
+    def get_or_update_details(  # type: ignore
         cls: BaseSchema, values: Dict[str, Any]
     ) -> Dict[str, Any]:
         """Validate that 'get' or 'update' details are supplied."""
@@ -112,7 +120,7 @@ def generate_request_callback_jwe(webhook: PolicyPreWebhook) -> str:
         scopes=[PRIVACY_REQUEST_CALLBACK_RESUME],
         iat=datetime.now().isoformat(),
     )
-    return generate_jwe(json.dumps(jwe.dict()))
+    return generate_jwe(json.dumps(jwe.dict()), config.security.APP_ENCRYPTION_KEY)
 
 
 class PrivacyRequest(Base):  # pylint: disable=R0904
@@ -138,7 +146,7 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
     # Who approved/denied the request
     reviewed_by = Column(
         String,
-        ForeignKey(FidesopsUser.id_field_path, ondelete="SET NULL"),
+        ForeignKey(FidesUser.id_field_path, ondelete="SET NULL"),
         nullable=True,
     )
     client_id = Column(
@@ -184,12 +192,12 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
     )
 
     reviewer = relationship(
-        FidesopsUser, backref=backref("privacy_request", passive_deletes=True)
+        FidesUser, backref=backref("privacy_request", passive_deletes=True)
     )
     paused_at = Column(DateTime(timezone=True), nullable=True)
 
     @classmethod
-    def create(cls, db: Session, *, data: Dict[str, Any]) -> FidesopsBase:
+    def create(cls, db: Session, *, data: Dict[str, Any]) -> FidesBase:
         """
         Check whether this object has been passed a `requested_at` value. Default to
         the current datetime if not.
@@ -200,13 +208,16 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
 
     def delete(self, db: Session) -> None:
         """
-        Clean up the cached data related to this privacy request before deleting this
-        object from the database
+        Clean up the cached and persisted data related to this privacy request before
+        deleting this object from the database
         """
         cache: FidesopsRedis = get_cache()
         all_keys = get_all_cache_keys_for_privacy_request(privacy_request_id=self.id)
         for key in all_keys:
             cache.delete(key)
+
+        for provided_identity in self.provided_identities:
+            provided_identity.delete(db=db)
         super().delete(db=db)
 
     def cache_identity(self, identity: PrivacyRequestIdentity) -> None:
@@ -220,6 +231,39 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
                     value,
                 )
 
+    def persist_identity(self, db: Session, identity: PrivacyRequestIdentity) -> None:
+        """
+        Stores the identity provided with the privacy request in a secure way, compatible with
+        blind indexing for later searching and audit purposes.
+        """
+        identity_dict: Dict[str, Any] = dict(identity)
+        for key, value in identity_dict.items():
+            if value is not None:
+                hashed_value = ProvidedIdentity.hash_value(value)
+                ProvidedIdentity.create(
+                    db=db,
+                    data={
+                        "privacy_request_id": self.id,
+                        "field_name": key,
+                        # We don't need to manually encrypt this field, it's done at the ORM level
+                        "encrypted_value": {"value": value},
+                        "hashed_value": hashed_value,
+                    },
+                )
+
+    def get_persisted_identity(self) -> PrivacyRequestIdentity:
+        """
+        Retrieves persisted identity fields from the DB.
+        """
+        schema = PrivacyRequestIdentity()
+        for field in self.provided_identities:
+            setattr(
+                schema,
+                field.field_name.value,
+                field.encrypted_value["value"],
+            )
+        return schema
+
     def cache_task_id(self, task_id: str) -> None:
         """Sets a task_id for this privacy request's asynchronous execution."""
         cache: FidesopsRedis = get_cache()
@@ -388,7 +432,7 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
         """
         cache: FidesopsRedis = get_cache()
         prefix = f"MANUAL_MASK__{self.id}__{collection.value}"
-        value_dict: Optional[Dict[str, int]] = cache.get_encoded_objects_by_prefix(
+        value_dict: Optional[Dict[str, int]] = cache.get_encoded_objects_by_prefix(  # type: ignore
             prefix
         )
         return list(value_dict.values())[0] if value_dict else None
@@ -403,10 +447,10 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
         # temp fix for circular dependency
         from fidesops.service.connectors import HTTPSConnector, get_connector
 
-        https_connector: HTTPSConnector = get_connector(webhook.connection_config)
+        https_connector: HTTPSConnector = get_connector(webhook.connection_config)  # type: ignore
         request_body = SecondPartyRequestFormat(
             privacy_request_id=self.id,
-            direction=webhook.direction.value,
+            direction=webhook.direction.value,  # type: ignore
             callback_type=webhook.prefix,
             identity=self.get_cached_identity_data(),
         )
@@ -421,7 +465,7 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
             }
 
         logger.info(f"Calling webhook {webhook.key} for privacy_request {self.id}")
-        response: Optional[SecondPartyResponseFormat] = https_connector.execute(
+        response: Optional[SecondPartyResponseFormat] = https_connector.execute(  # type: ignore
             request_body.dict(),
             response_expected=response_expected,
             additional_headers=headers,
@@ -429,7 +473,7 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
         if not response:
             return
 
-        response_body = SecondPartyResponseFormat(**response)
+        response_body = SecondPartyResponseFormat(**response)  # type: ignore
 
         # Cache any new identities
         if response_body.derived_identity and any(
@@ -438,6 +482,8 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
             logger.info(
                 f"Updating known identities on privacy request {self.id} from webhook {webhook.key}."
             )
+            # Don't persist derived identities because they aren't provided directly
+            # by the end user
             self.cache_identity(response_body.derived_identity)
 
         # Pause execution if instructed
@@ -491,6 +537,67 @@ class PrivacyRequest(Base):  # pylint: disable=R0904
         )
 
 
+class ProvidedIdentityType(EnumType):
+    """Enum for privacy request identity types"""
+
+    email = "email"
+    phone_number = "phone_number"
+
+
+class ProvidedIdentity(Base):  # pylint: disable=R0904
+    """
+    A table for storing identity fields and values provided at privacy request
+    creation time.
+    """
+
+    privacy_request_id = Column(
+        String,
+        ForeignKey(PrivacyRequest.id_field_path),
+        nullable=False,
+    )
+    privacy_request = relationship(
+        PrivacyRequest,
+        backref="provided_identities",
+    )  # Which privacy request this identity belongs to
+
+    field_name = Column(
+        EnumColumn(ProvidedIdentityType),
+        index=False,
+        nullable=False,
+    )
+    hashed_value = Column(
+        String,
+        index=True,
+        unique=False,
+        nullable=True,
+    )  # This field is used as a blind index for exact match searches
+    encrypted_value = Column(
+        MutableDict.as_mutable(
+            StringEncryptedType(
+                JSONTypeOverride,
+                config.security.APP_ENCRYPTION_KEY,
+                AesGcmEngine,
+                "pkcs5",
+            )
+        ),
+        nullable=True,
+    )  # Type bytea in the db
+
+    @classmethod
+    def hash_value(
+        cls,
+        value: str,
+        encoding: str = "UTF-8",
+    ) -> tuple[str, str]:
+        """Utility function to hash a user's password with a generated salt"""
+        SALT = "a-salt"
+        hashed_value = hash_with_salt(
+            value.encode(encoding),
+            SALT.encode(encoding),
+        )
+        return hashed_value
+
+
 # Unique text to separate a step from a collection address, so we can store two values in one.
 PAUSED_SEPARATOR = "__fidesops_paused_sep__"
 
