@@ -22,8 +22,8 @@ class FilterPostProcessorConfiguration(StrategyConfiguration):
 
     field: str
     value: Union[str, IdentityParamRef]
-    exact: Optional[bool] = True
-    case_sensitive: Optional[bool] = True
+    exact: bool = True
+    case_sensitive: bool = True
 
 
 class OffsetPaginationConfiguration(StrategyConfiguration):
