@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import json
 import logging
 import re
@@ -5,6 +7,8 @@ from collections import defaultdict
 from functools import reduce
 from typing import Any, Dict, List, Optional, Set, Tuple
 
+import yaml
+from fideslib.core.config import load_file
 from multidimensional_urlencode import urlencode as multidimensional_urlencode
 
 from fidesops.common_exceptions import FidesopsException
@@ -17,6 +21,13 @@ logger = logging.getLogger(__name__)
 FIDESOPS_GROUPED_INPUTS = "fidesops_grouped_inputs"
 
 
+def load_config(filename: str) -> Dict:
+    """Loads the saas config from the yaml file"""
+    yaml_file = load_file([filename])
+    with open(yaml_file, "r") as file:
+        return yaml.safe_load(file).get("saas_config", [])
+
+
 def merge_fields(target: Field, source: Field) -> Field:
     """Replaces source references and identities if they are available from the target"""
     if source.references is not None:
@@ -44,8 +55,8 @@ def get_collection_grouped_inputs(
     collections: List[Collection], name: str
 ) -> Optional[Set[str]]:
     """Get collection grouped inputs"""
-    collection: Collection = next(
-        (collect for collect in collections if collect.name == name), {}
+    collection: Collection | None = next(
+        (collect for collect in collections if collect.name == name), None
     )
     if not collection:
         return set()
@@ -56,8 +67,8 @@ def get_collection_after(
     collections: List[Collection], name: str
 ) -> Set[CollectionAddress]:
     """If specified, return the collections that need to run before the current collection for saas configs"""
-    collection: Collection = next(
-        (collect for collect in collections if collect.name == name), {}
+    collection: Collection | None = next(
+        (collect for collect in collections if collect.name == name), None
     )
     if not collection:
         return set()
